.. include:: README.rst

.. toctree::
    :hidden:
    :glob:

    LICENSE
    README
    api/*
    txt/*

#######
RECHTEN
#######

.. image:: jpg/20140730_011.jpg 
    :align: center

########
CAMPAGNE
########

.. toctree::
    :includehidden:
    :glob:

    api/koning.*

####
DOCS
####

.. toctree::
    :includehidden:
    :glob:

    txt/*

#######
CONTACT
#######     

* Bart Thate - 47 jaar
* IRC: botfather on #dunkbots irc.freenode.net
* email: bthate@dds.nl
* http://pypi.python.org/pypi/koning
* http://pikacode.com/bthate/wet
